==> ekup-1.1.1.2_Test_2024-06-07.zip: webroot/ngax/scripts/angular-gettext-custom.js <==
angular.module('backupApp').run(['gettextCatalog', function (gettextCatalog) {
    /* jshint -W100 */
        gettextCatalog.setStrings('fr', {
            'Add a recipient': 'Ajouter un destinataire',
            'Alerts': 'Alertes',
            'All': 'Tout',
            'An email has been sent to the recipients. If it appear in the SPAM folder think to mark the sender email as trusted one.': 'Un email a été envoyé aux destinataires. Si le mail apparaît dans les SPAM pensez à marquer l\'expéditeur comme étant légitime.',
            'An existing backup has the same name.': 'Le nom est utilisé par une configuration existante.',
            'An existing backup is targetting the same folder.': 'Le chemin de destination est déjà utilisé par une autre configuration',
            'An existing backup refer to the same database.': 'La base de donnée de la configuration est la même que celle d\'une configuration existante',
            'Backup': 'Sauvegarde',
            'Change configuration': 'Modifier la configuration',
            'Change file': 'Changer de fichier',
            'Change server path': 'Changer le chemin sur le serveur',
            'Choose a file': 'Choisir un fichier',
            'Confirm password': 'Confirmez votre mot de passe',
            'Complete journal': 'Journal complet',
            'Create': 'Créer',
            'Create Password': 'Créer un mot de passe',
            'Data': 'Données',
            'Do you really want to delete the backup: "{{name}}" ? (no rollback possible)': 'Voulez-vous vraiment supprimer la sauvegarde : "{{name}}" ? (Aucun retour arrière possible)',
            'Duration': 'Durée',
            'Ekup Reset password': 'Ekup mot de passe réinitialisation',
            'Email test sent': 'Email de test envoyé',
            'End date': 'Date de fin',
            'Enter mail here': 'Entrez un email',
            'Enter the destination path prefix': 'Saisir le préfixe du chemin de destination',
            'Elements {{from}} to {{to}} of {{total}}': 'Éléments {{from}} à {{to}} sur {{total}}',
            'Elements per page:': 'Éléments par page:',
            'Error': 'Erreur',
            'Errors': 'Erreurs',
            'Failed': 'Echec',
            'Fatal': 'Critique',
            'File': 'Fichier',
            'Files': 'Fichiers',
            'Finish': 'Terminer',
            'Forget password?' : 'Mot de passe oublié ?',
            'Go back': 'Retour',
            'Go back to': 'Retourner à',
            'Hide': 'Masquer',
            'Hide all': 'Masquer la totalité',
            'If you forget your password we can reset it. An email will be sent to the user email set in the settings. This code will be asked to recreate your password.': 'Si vous avez oublié votre mot de passe nous pouvons le réinitialiser. Un code vous sera envoyé à l\'adresse mail utilisateur renseignée dans la configuration de l\'application. Ce code vous sera demandé pour finaliser la réinitialisation de votre mot de passe.',
            'Import failed for {{name}}': 'Import de {{name}} a échoué',
            'Import from server': 'Importer depuis le serveur',
            'Import of {{name}} in progress': 'Import de {{name}} en cours',
            'Import of {{name}} complete': 'Import de {{name}} ternminé',
            'Importing...': 'Import en cours',
            'It can only be change if no backup is configured to not breack the existing ones.': 'Seulement modifiable si aucune sauvegarde n\'a été configurée pour ne pas casser les sauvegardes existantes.',
            'Language': 'Langue',
            'Last backup:': 'Dernière sauvegarde :',
            'Last backup status:': 'Etat de la dernière sauvegarde :',
            'List of configuration found': 'Liste des jobs trouvés',
            'List of recipients': 'Liste des destinataires',
            'Load previous configurations stored on server': 'Récupérer vos précédents jobs poussés sur le serveur',
            'Looking for configuration on server...': 'Recherche de configuration sur le serveur...',
            'Logs history': 'Historique de logs',
            'Mail is not valid': "L\'email n'est pas valide.",
            'Max number of recipient reached ({{max}} max)': 'Nombre maximum de destinataires atteint ({{max}} maximum)',
            'Must contains a mixture of numbers, lowercase and uppercase letters': 'Doit contenir un mélange de chiffres, minuscules et majuscules.',
            'Must contains at least 8 characters.': 'Doit contenir au moins 8 caractères',
            'My backups': 'Mes sauvegardes',
            'No backup have been created yet.': 'Aucune sauvegarde n\'a été configurée.',
            'No code generated or code has expired': 'Aucun code généré, ou code expiré.',
            'No configuration found on server or you already imported them.': 'Aucun job sur le serveur trouvé ou vous les avez déjà d\'installés.',
            'No filters has been set.': 'Aucun filtres configurés',
            'No notifications': 'Aucune notification',
            'None': 'Aucun',
            'Not logged in': 'Utilisateur non connecté',
            'Notifications list': 'Liste des notifications',
            'Nothing will be deleted. The backup size will grow with each change. When the storage limit will be reached, there won\'t be new backup. You will be notified by a failed backup in the backup report.': 'Rien ne sera supprimé. La taille de la sauvegarde augmentera à chaque modification. Lorsque vous aurez atteint la limite de stockage, il n\'y aura plus de sauvegarde réalisée. Vous serez notifié d\'un éventuel échec dans votre rapport de sauvegarde.',
            'Open restore folder': 'Ouvrir le dossier de restauration',
            'Operation': 'Opération',
            'Operation type': 'Type d\'opération',
            'Operation details': 'Détails de l\'opération',
            'Operation journal': 'Journal d\'opération',
            'Or': 'Ou',
            'Paused': 'Stopé',
            'Passphrase (optional)': 'Phrase secrète (facultative)',
            'Path': 'Chemin',
            'Path prefix on server': 'Préfixe du chemin sur le serveur',
            'Page {{currentPage}} of {{totalPages}}': 'Page {{currentPage}} sur {{totalPages}}',
            'Recipient': 'Destinataire',
            'Recipients': 'Destinataires',
            'Reset password': 'Réinitialiser',
            'Reset password Code': 'Code de réinitialisation',
            'Restore complete': 'Restauration terminéee',
            'Restore complete. Do you want to open the restore folder ?' : 'Restauration terminéee, voulez-vous ouvrir le dossier de restauration ?',
            'Restore from an existing backup': 'Restaurer depuis une configuration existante',
            'Restore location': 'Emplacement de la restauration',
            'Restoring files': 'Restauration des fichiers en cours...',
            'Retrieve from server': 'Récupération depuis le serveur',
            'Running': 'En cours',
            'Schedules': 'Horaires',
            'Schedule your backup': 'Planification de la sauvegarde',
            'Select configuration': 'Selection des jobs',
            'See all notifications': 'Voir toutes les notifications',
            'Service actions': 'Actions de service',
            'Send': 'Envoyer',
            'Send code': 'Envoyer le code',
            'Send test email': 'Envoyer un email de test',
            'Setup options': 'Choix de parametrage',
            'SFTP config': 'Configuration SFTP',
            'SFTP server': 'Serveur SFTP',
            'Sign In': 'Se connecter',
            'Size:': 'Taille :',
            'Size after compression': 'Taille après compression',
            'Status': 'Statut',
            'Start date': 'Date de début',
            'Startup': 'Démarrage',
            'Storage options': 'Options de stockage',
            'Success': 'Succès',
            'Successfully saved': 'Enregistrement réussi',
            'Summary': 'Récapitulatif',
            'Show complete journal': 'Afficher le journal complet',
            'Show details': 'Afficher les détails',
            'Test sending emails...': 'Test de l\'envoi d\'emails...',
            'Testing stage': 'Etape de test',
            'The backup has been wrongly setup (the targeted folder is not accessible). Try to delete it and recreate it.': 'La sauvegarde a été créée avec une configuration incorrecte (le dossier visé n\'est pas accessible). Essayez de la supprimer puis de la recréer.',
            'The configuration for "{{backupname}}" backup has been saved.': 'La configuration de la sauvegarde "{{backupname}}" a bien était enregistré.',
            'The Folder already exists and used by another job.': 'Le dossier visé existe déjà et est utilisé par une autre tache.',
            'The Folder does not exists.': 'Le répertoire demandé n\'existe pas.',
            'The path prefix will be applied on each backup.': 'Le préfixe du chemin est appliqué à chaque backup.',
            'The smtp config is wrong or no email has been set for the user.': 'La configuration SMTP est incorrecte, ou l\'utilisateur n\'a pas de mail paramétré.',
            'The targeted Folder does not exists.' : 'Le répertoire visé n\'existe pas.',
            'The targeted folder in the imported files is already used.' : 'Le dossier de destination défini dans le fichier importé est déjà utilisé.',
            'This mail is used to notify the user (ex: reset password) and prefill the recipient list (step 6) during backup creation. If you change this mail it will not update the mail for alert in the existing backup.': 'Cet email est utilisé pour notifier l\'utilisateur (ex: mot de passe oublié) et pour préremplir la liste des destinataires des alertes durant la création d\'une sauvegarde (étape 6). La modification de ce mail n\'entraîne pas la modification des destinataires dans les sauvegardes existantes.',
            'This password will be asked each time you want to access Ekup app.': 'Ce mot de passe vous sera demandé à chaque fois que que vous accéderez à l\'application Ekup.',
            'Track levels' : 'Notifier quand',
            'Unknown': 'Inconnu',
            'Update backup configuration': 'Modifier la configuration de sauvegarde',
            'Use default encryption key (Recommended)': 'Utiliser la phrase secrète par défaut (Recommandé)',
            'Use default restore path (Recommended)': 'Utiliser le chemin par défaut (Recommandé)',
            'Use ssh key': 'Utiliser la clé ssh',
            'User information': 'Information utilisateur',
            'User preferences': 'Préférences de l\'utilisateur',
            'Warning': 'Avertissement',
            'We encountered an error while sending the email.': 'Nous avons rencontré une erreur lors de l\'envoi du mail.',
            'Welcome to Ekup': 'Bienvenue sur Ekup',
            'Where do you want to restore from?': 'Quelle source de données voulez vous restaurer?',
            'You can exclude files and folders contained in a selected folder by clicking on them. (a red cross will appear instead of the green check)': 'Vous pouvez exclure des fichiers et dossiers contenus dans un dossier sélectionné en les décochant. (une croix rouge remplacera la coche verte)',
            'You can set a passphrase to protect your backups and be accessible only by you. Be caustious to remember this passphrase, it will be asked to make a restore from a different computer or installtion.': 'Vous pouvez utiliser une phrase secrète pour protéger votre sauvegarde et la rendre seulement accessible par vous. Gardez-la en mémoire, elle vous sera demandée pour pouvoir restorer votre sauvegarde sur un autre ordinateur ou installation.',
            'You must select at least one notification level': "Vous devez sélectionner au moins un niveau d'alerte",
            'Your notifications': 'Vos notifications'
        });
    }
]);

==> ekup-1.1.2.1_Test_2024-10-08.zip: webroot/ngax/scripts/angular-gettext-custom.js <==
angular.module('backupApp').run(['gettextCatalog', function (gettextCatalog) {
    /* jshint -W100 */
        gettextCatalog.setStrings('fr', {
            'Add a recipient': 'Ajouter un destinataire',
            'Alerts': 'Alertes',
            'All': 'Tout',
            'An email has been sent to the recipients. If it appear in the SPAM folder think to mark the sender email as trusted one.': 'Un email a été envoyé aux destinataires. Si le mail apparaît dans les SPAM pensez à marquer l\'expéditeur comme étant légitime.',
            'An existing backup has the same name.': 'Le nom est utilisé par une configuration existante.',
            'An existing backup is targetting the same folder.': 'Le chemin de destination est déjà utilisé par une autre configuration',
            'An existing backup refer to the same database.': 'La base de donnée de la configuration est la même que celle d\'une configuration existante',
            'Backup name': 'Nom de la sauvegarde',
            'Backup': 'Sauvegarde',
            'Change configuration': 'Modifier la configuration',
            'Change file': 'Changer de fichier',
            'Change server path': 'Changer le chemin sur le serveur',
            'Choose a file': 'Choisir un fichier',
            'Confirm password': 'Confirmez votre mot de passe',
            'Complete journal': 'Journal complet',
            'Create': 'Créer',
            'Create Password': 'Créer un mot de passe',
            'Data': 'Données',
            'Do you really want to delete the backup: "{{name}}" ? (no rollback possible)': 'Voulez-vous vraiment supprimer la sauvegarde : "{{name}}" ? (Aucun retour arrière possible)',
            'Duration': 'Durée',
            'Ekup Reset password': 'Ekup mot de passe réinitialisation',
            'Email test sent': 'Email de test envoyé',
            'Email notifications': 'Notifications par e-mail',
            'E-mail address': 'Adresse e-mail',
            'End date': 'Date de fin',
            'Enter mail here': 'Entrez un email',
            'Enter the destination path prefix': 'Saisir le préfixe du chemin de destination',
            'Enter the sender email': 'Entrez l\'e-mail de l\'expéditeur',
            'Enter the name to display in the from': 'Entrez le nom à afficher dans le champ de',
            'Elements {{from}} to {{to}} of {{total}}': 'Éléments {{from}} à {{to}} sur {{total}}',
            'Elements per page:': 'Éléments par page:',
            'Error': 'Erreur',
            'Errors': 'Erreurs',
            'Failed': 'Echec',
            'Fatal': 'Critique',
            'File': 'Fichier',
            'Files': 'Fichiers',
            'Finish': 'Terminer',
            'First backup': 'Première sauvegarde',
            'Forget password?' : 'Mot de passe oublié ?',
            'Go back': 'Retour',
            'Go back to': 'Retourner à',
            'Hide': 'Masquer',
            'Hide all': 'Masquer la totalité',
            'If a date was missed, the task starts as soon as possible.': 'Si une date a été manquée, la tâche démarrera dès que possible.',
            'If you forget your password we can reset it. An email will be sent to the user email set in the settings. This code will be asked to recreate your password.': 'Si vous avez oublié votre mot de passe nous pouvons le réinitialiser. Un code vous sera envoyé à l\'adresse mail utilisateur renseignée dans la configuration de l\'application. Ce code vous sera demandé pour finaliser la réinitialisation de votre mot de passe.',
            'Import failed for {{name}}': 'Import de {{name}} a échoué',
            'Import from server': 'Importer depuis le serveur',
            'Import of {{name}} in progress': 'Import de {{name}} en cours',
            'Import of {{name}} complete': 'Import de {{name}} ternminé',
            'Importing...': 'Import en cours',
            'It can only be change if no backup is configured to not breack the existing ones.': 'Seulement modifiable si aucune sauvegarde n\'a été configurée pour ne pas casser les sauvegardes existantes.',
            'Language': 'Langue',
            'Last backup:': 'Dernière sauvegarde :',
            'Last backup status:': 'Etat de la dernière sauvegarde :',
            'List of configuration found': 'Liste des jobs trouvés',
            'List of recipients': 'Liste des destinataires',
            'Load previous configurations stored on server': 'Récupérer vos précédents jobs poussés sur le serveur',
            'Looking for configuration on server...': 'Recherche de configuration sur le serveur...',
            'Logs history': 'Historique de logs',
            'Mail is not valid': "L\'email n'est pas valide.",
            'Max number of recipient reached ({{max}} max)': 'Nombre maximum de destinataires atteint ({{max}} maximum)',
            'Must contains a mixture of numbers, lowercase and uppercase letters': 'Doit contenir un mélange de chiffres, minuscules et majuscules.',
            'Must contains at least 8 characters.': 'Doit contenir au moins 8 caractères',
            'My backups': 'Mes sauvegardes',
            'Next step': 'Etape suivante',
            'No backup have been created yet.': 'Aucune sauvegarde n\'a été configurée.',
            'No code generated or code has expired': 'Aucun code généré, ou code expiré.',
            'No configuration found on server or you already imported them.': 'Aucun job sur le serveur trouvé ou vous les avez déjà d\'installés.',
            'No filters has been set.': 'Aucun filtres configurés',
            'No notifications': 'Aucune notification',
            'None': 'Aucun',
            'Not logged in': 'Utilisateur non connecté',
            'Notifications list': 'Liste des notifications',
            'Notify for': 'Notifier pour',
            'Nothing will be deleted. The backup size will grow with each change. When the storage limit will be reached, there won\'t be new backup. You will be notified by a failed backup in the backup report.': 'Rien ne sera supprimé. La taille de la sauvegarde augmentera à chaque modification. Lorsque vous aurez atteint la limite de stockage, il n\'y aura plus de sauvegarde réalisée. Vous serez notifié d\'un éventuel échec dans votre rapport de sauvegarde.',
            'Open restore folder': 'Ouvrir le dossier de restauration',
            'Operation': 'Opération',
            'Operation type': 'Type d\'opération',
            'Operation details': 'Détails de l\'opération',
            'Operation journal': 'Journal d\'opération',
            'Or': 'Ou',
            'Paused': 'Stopé',
            'Passphrase (optional)': 'Phrase secrète (facultative)',
            'Path': 'Chemin',
            'Path prefix on server': 'Préfixe du chemin sur le serveur',
            'Password': 'Mot de passe',
            'Page {{currentPage}} of {{totalPages}}': 'Page {{currentPage}} sur {{totalPages}}',
            'Previous step': 'Etape précédente',
            'Recipient': 'Destinataire',
            'Recipients': 'Destinataires',
            'Reset password': 'Réinitialiser',
            'Reset password Code': 'Code de réinitialisation',
            'Restore complete': 'Restauration terminéee',
            'Restore complete. Do you want to open the restore folder ?' : 'Restauration terminéee, voulez-vous ouvrir le dossier de restauration ?',
            'Restore from an existing backup': 'Restaurer depuis une configuration existante',
            'Restore location': 'Emplacement de la restauration',
            'Restoring files': 'Restauration des fichiers en cours...',
            'Retrieve from server': 'Récupération depuis le serveur',
            'Running': 'En cours',
            'Schedules': 'Horaires',
            'Scheduling': 'Planification',
            'Schedule your backup': 'Planification de la sauvegarde',
            'Select configuration': 'Selection des jobs',
            'See all notifications': 'Voir toutes les notifications',
            'Service actions': 'Actions de service',
            'Send': 'Envoyer',
            'Send code': 'Envoyer le code',
            'Send test email': 'Envoyer un email de test',
            'Sender email': 'E-mail de l\'expéditeur',
            'Sender password': 'Mot de passe de l\'expéditeur',
            'Setup options': 'Choix de parametrage',
            'SFTP config': 'Configuration SFTP',
            'SFTP server': 'Serveur SFTP',
            'SMTP Config': 'Configuration SMTP',
            'SMTP server address': 'Adresse du serveur SMTP',
            'Sender alias': 'Expéditeur alias',
            'Sign In': 'Se connecter',
            'Size:': 'Taille :',
            'Size after compression': 'Taille après compression',
            'Status': 'Statut',
            'Start date': 'Date de début',
            'Startup': 'Démarrage',
            'Storage options': 'Options de stockage',
            'Success': 'Succès',
            'Successfully saved': 'Enregistrement réussi',
            'Summary': 'Récapitulatif',
            'Show complete journal': 'Afficher le journal complet',
            'Show details': 'Afficher les détails',
            'Test sending emails...': 'Test de l\'envoi d\'emails...',
            'Testing stage': 'Etape de test',
            'The backup has been wrongly setup (the targeted folder is not accessible). Try to delete it and recreate it.': 'La sauvegarde a été créée avec une configuration incorrecte (le dossier visé n\'est pas accessible). Essayez de la supprimer puis de la recréer.',
            'The configuration for "{{backupname}}" backup has been saved.': 'La configuration de la sauvegarde "{{backupname}}" a bien été enregistrée.',
            'The Folder already exists and used by another job.': 'Le dossier visé existe déjà et est utilisé par une autre tache.',
            'The Folder does not exists.': 'Le répertoire demandé n\'existe pas.',
            'The path prefix will be applied on each backup.': 'Le préfixe du chemin est appliqué à chaque backup.',
            'The smtp config is wrong or no email has been set for the user.': 'La configuration SMTP est incorrecte, ou l\'utilisateur n\'a pas de mail paramétré.',
            'The settings will be saved once you click the save button': 'Les paramètres seront enregistrés une fois que vous cliquerez sur le bouton de sauvegarde',
            'The targeted Folder does not exists.' : 'Le répertoire visé n\'existe pas.',
            'The targeted folder in the imported files is already used.' : 'Le dossier de destination défini dans le fichier importé est déjà utilisé.',
            'This exclusion is indicated by a red cross in place of a blue checkmark.': 'Cette exclusion est indiquée par une croix rouge à la place d\'une coche bleue.',
            'This mail is used to notify the user (ex: reset password) and prefill the recipient list (step 6) during backup creation. If you change this mail it will not update the mail for alert in the existing backup.': 'Cet email est utilisé pour notifier l\'utilisateur (ex: mot de passe oublié) et pour préremplir la liste des destinataires des alertes durant la création d\'une sauvegarde (étape 6). La modification de ce mail n\'entraîne pas la modification des destinataires dans les sauvegardes existantes.',
            'This password will be asked each time you want to access Ekup app.': 'Ce mot de passe vous sera demandé à chaque fois que que vous accéderez à l\'application Ekup.',
            'Track levels' : 'Notifier quand',
            'Unknown': 'Inconnu',
            'Update backup configuration': 'Modifier la configuration de sauvegarde',
            'Use default encryption key (Recommended)': 'Utiliser la phrase secrète par défaut (Recommandé)',
            'Use default restore path (Recommended)': 'Utiliser le chemin par défaut (Recommandé)',
            'Use ssh key': 'Utiliser la clé ssh',
            'User information': 'Information utilisateur',
            'User preferences': 'Préférences de l\'utilisateur',
            'Warning': 'Avertissement',
            'We encountered an error while sending the email.': 'Nous avons rencontré une erreur lors de l\'envoi du mail.',
            'Welcome to Ekup': 'Bienvenue sur Ekup',
            'Where do you want to restore from?': 'Quelle source de données voulez vous restaurer?',
            'You can exclude files and folders contained in a selected folder by clicking on them. (a red cross will appear instead of the green check)': 'Vous pouvez exclure des fichiers et dossiers contenus dans un dossier sélectionné en les décochant. (une croix rouge remplacera la coche verte)',
            'You can set a passphrase to protect your backups and be accessible only by you. Be caustious to remember this passphrase, it will be asked to make a restore from a different computer or installtion.': 'Vous pouvez utiliser une phrase secrète pour protéger votre sauvegarde et la rendre seulement accessible par vous. Gardez-la en mémoire, elle vous sera demandée pour pouvoir restorer votre sauvegarde sur un autre ordinateur ou installation.',
            'You can exclude certain files and subfolders contained in a selected folder by unchecking them.': 'Vous pouvez exclure certains fichiers et sous-dossiers contenus dans un dossier sélectionné en les décochant.',
            'You must select at least one notification level': "Vous devez sélectionner au moins un niveau d'alerte",
            'Your notifications': 'Vos notifications'
        });
    }
]);
